About
-----
Clipt (command line interface plotting tool) uses clasp and matplotlib
to aid in plotting data files using matplotlib directly from the command
line using a extensive set of options.  See the clasp documentation for
imformation about using config files.

https://clipt.readthedocs.io/

Clipt was built using clasp: https://clasp.readthedocs.io/
which in turn depends on click: https://palletsprojects.com/p/click/


Installation
------------

::

    pip install clipt

Usage
-----

see::

    cl_plot --help

Autocomplete
------------

::

    _CL_PLOT_COMPLETE=source cl_plot > clipt_complete.sh


In your .bash_profile::

    source path/to/bin/clipt_complete.sh


Source Code
-----------

* clipt: https://bitbucket.org/stephenwasilewski/clipt

Licence
-------

| Copyright (c) 2018 Stephen Wasilewski
| This Source Code Form is subject to the terms of the Mozilla Public
| License, v. 2.0. If a copy of the MPL was not distributed with this
| file, You can obtain one at http://mozilla.org/MPL/2.0/.

